[pypy-svn] r67714 - pypy/branch/asmgcroot-callback/pypy/translator/c/test

arigo at codespeak.net arigo at codespeak.net
Wed Sep 16 12:46:03 CEST 2009


Author: arigo
Date: Wed Sep 16 12:46:02 2009
New Revision: 67714

Modified:
   pypy/branch/asmgcroot-callback/pypy/translator/c/test/test_standalone.py
Log:
Increase the level of recursion, as an attempt to fight off
modern gcc's which are able to optimize the recursion by doing
only one recursive call in assembler for every 10 recursive
calls in C...


Modified: pypy/branch/asmgcroot-callback/pypy/translator/c/test/test_standalone.py
==============================================================================
--- pypy/branch/asmgcroot-callback/pypy/translator/c/test/test_standalone.py	(original)
+++ pypy/branch/asmgcroot-callback/pypy/translator/c/test/test_standalone.py	Wed Sep 16 12:46:02 2009
@@ -333,8 +333,8 @@
                 return 0
 
         def bootstrap():
-            # recurse a lot, like 2500 times
-            recurse(2500)
+            # recurse a lot, like 19500 times
+            recurse(19500)
             state.count += 1
 
         def entry_point(argv):
@@ -368,7 +368,8 @@
 
         # recursing should crash with only 32 KB of stack,
         # and it should eventually work with more stack
-        for test_kb in [32, 128, 512, 1024, 2048, 4096, 8192, 16384]:
+        for test_kb in [32, 128, 512, 1024, 2048, 4096, 8192, 16384,
+                        32768, 65536]:
             print >> sys.stderr, 'Trying with %d KB of stack...' % (test_kb,),
             try:
                 data = cbuilder.cmdexec(str(test_kb * 1024))



More information about the Pypy-commit mailing list